@@ -1,6 +1,6 @@
-activity_frequency_trace <- function(eventlog) {
-	cases <- case_list(eventlog)
-	eventlog %>%
+activity_frequency_trace <- function(log) {
+	cases <- case_list(log)
+	log %>%
 		activity_frequency_case() %>%
 		merge(cases) %>%
 		arrange(trace) %>%
