@@ -6,6 +6,9 @@ processing_time_activity <- function(log, units, work_schedule) {
 	log %>%
 		processing_time_activity_instance(units = units, work_schedule = work_schedule) -> raw
 
+	# Store time units, because dplyr transformations remove the attributes.
+	time_units <- attr(raw, "units")
+
 	log %>%
 		distinct(!!activity_instance_id_(log), !!activity_id_(log)) -> dict
 
@@ -20,6 +23,6 @@ processing_time_activity <- function(log, units, work_schedule) {
 		arrange(desc(relative_frequency)) -> output
 
 	attr(output, "raw") <- raw
-
+	attr(output, "units") <- time_units
 	return(output)
 }
