@@ -4,8 +4,8 @@ resource_involvement_case <- function(log) {
 	relative <- NULL
 
 	log %>%
-		group_by(!!case_id_(log),  !!resource_id_(log)) %>%
-		#summarize() %>%
+		distinct(!!case_id_(log),  !!resource_id_(log)) %>%
+		group_by(!!case_id_(log)) %>%
 		summarize(absolute = n()) %>%
 		mutate(relative = absolute/n_resources(log))
 }
